Module reader

Module reader 

OBJ file reader.

Functions

read_obj
Read an OBJ file from a string and return a triangle mesh.
read_obj_solid
Read an OBJ file and import it as a solid with one planar face per triangle.